dmart library

Support for doing something awesome.

More dartdocs go here.

Classes

ActionRequest
ActionRequest is a class that represents a request to the API to perform an action on a resource.
ActionRequestRecord
ActionRequestRecord is a class that represents a record in an ActionRequest.
ActionResponse
ActionResponseAttachments
ActionResponseRecord
ApiQueryResponse
ApiQueryResponseAttributes
ApiResponse<T>
BaseResponse
CheckExistingParams
ConfirmOTPRequest
CreateUserAttributes
CreateUserRequest
CreateUserResponse
Description
Displayname
Dmart
Dmart class that has all the methods to interact with the Dmart server.
Error
GetPayloadRequest
LoginAttributes
LoginRequest
LoginResponse
MetaExtended
PasswordResetRequest
Payload
Payload is a class that represents the payload of a resource.
Permission
Permission is a class that represents the permissions of a user on a resource.
ProfileResponse
ProfileResponseRecord
ProfileResponseRecordAttributes
ProgressTicketRequest
QueryRequest
QueryRequest is a class that represents a request to the API to query resources.
Record
A model class for the record object
ResponseEntry
ResponseRecord
ResponseRecordAttributes
RetrieveEntryRequest
RetrieveEntryRequest is a class that represents a request to the API to retrieve an entry from a resource.
SendOTPRequest
Translation