ActionResponse class
- Inheritance
-
- Object
- ApiResponse
- ActionResponse
Constructors
-
ActionResponse({required Status status, Error? error, List<
ActionResponseRecord> ? records, Attributes? attributes}) -
ActionResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- attributes ↔ Attributes?
-
getter/setter pair
- error → Error?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
records
↔ List<
ActionResponseRecord> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → Status
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the ActionResponse object to a JSON object.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited