BaseResponse class

Implementers

Constructors

BaseResponse({Status? status, List<Record>? records})
BaseResponse.fromJson(Map<String, dynamic> json)

Properties

hashCode int
The hash code for this object.
no setterinherited
records List<Record>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status Status?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the BaseResponse object to a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited