LoginResponse class

Inheritance

Constructors

LoginResponse({String? token, required Status? status, List<Record>? records})
LoginResponse.fromJson(Map<String, dynamic> json)
Converts the LoginResponse object to a JSON map.

Properties

displayname Displayname?
getter/setter pair
error Error?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
records List<Record>?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status Status?
getter/setter pairinherited
token String?
getter/setter pair
type UserType?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the LoginResponse object to a JSON map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited