ResponseRecord class

Implementers

Constructors

ResponseRecord({required ResourceType resourceType, required String uuid, required String shortname, required String subpath, required ResponseRecordAttributes attributes})
ResponseRecord.fromJson(Map<String, dynamic> json)
factory

Properties

attributes ResponseRecordAttributes
final
hashCode int
The hash code for this object.
no setterinherited
resourceType ResourceType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortname String
final
subpath String
final
uuid String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the ResponseRecord object to a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited