ProfileResponseRecord class
Constructors
- ProfileResponseRecord({required ResourceType resourceType, required String shortname, required String subpath, required ProfileResponseRecordAttributes attributes})
-
ProfileResponseRecord.fromJson(Map<
String, dynamic> json) -
factory
Properties
- attributes → ProfileResponseRecordAttributes
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- resourceType ↔ ResourceType
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortname ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited